Item class

Constructors

Item({String? label, String? symbol, String? id, bool? boxTwo, int? color})
Item.colorBoxes({String? id, String? label, String? symbol, bool? boxTwo = true, int? color})
Item.colors({String? id, bool? boxTwo = false, int? color})
Item.fromJson(String source)
factory
Item.fromMap(Map<String, dynamic> map)
factory
Item.symbols({String? id, bool? boxTwo = false, String? symbol})

Properties

boxTwo ↔ bool?
getter/setter pair
color ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol ↔ String?
getter/setter pair

Methods

copyWith({String? label, String? symbol, String? id, bool? boxTwo, int? color}) → Item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override